@@ -1,5 +1,3 @@
-#! /usr/bin/env python
-#
 # Copyright (c) 2011 Jason Ish
 # All rights reserved.
 #
@@ -28,13 +26,7 @@
 # An example of how to create a program much like u2spewfoo that comes
 # with Snort.
 
-"""A python reimplementation of Snort's u2spewfoo.
-
-::
-
-    usage: u2spewfoo.py <file>...
-
-"""
+"""A python reimplementation of Snort's u2spewfoo. """
 
 from __future__ import print_function
 
@@ -43,13 +35,24 @@ import os
 import socket
 import struct
 import string
+import logging
+import re
 
 if sys.argv[0] == __file__:
     sys.path.insert(
         0, os.path.abspath(os.path.join(__file__, "..", "..", "..")))
 
+try:
+    import argparse
+except ImportError as err:
+    from idstools.compat.argparse import argparse
+
 from idstools import unified2
 
+# Initialize logging.
+logging.basicConfig(level=logging.INFO, format="%(message)s")
+LOG = logging.getLogger()
+
 # Create a list of characters we consider printable.
 not_printable = "\t\r\n\x0b\x0c"
 printable = [c for c in string.printable if c not in not_printable]
@@ -76,6 +79,11 @@ def print_raw(raw):
         lines.append("%s %-48s  %s" % (prefix, as_hex, printable))
     return "\n".join(lines)
 
+def print_address(addr):
+    if len(addr) <= 15:
+        return addr
+    return re.sub(":::+", "::", addr.replace("0000", ""))
+
 def print_event(event):
     rows = (
         (("sensor id", "sensor-id", str),
@@ -89,8 +97,8 @@ def print_event(event):
          ("classification", "classification-id", str),
          ),
         (("priority", "priority", str),
-         ("ip source", "source-ip", str),
-         ("ip destination", "destination-ip", str),
+         ("ip source", "source-ip", print_address),
+         ("ip destination", "destination-ip", print_address),
          ),
         (("src port", "sport-itype", str),
          ("dest port", "dport-icode", str),
@@ -129,15 +137,25 @@ def print_packet(packet):
     print(print_raw(packet["data"]))
 
 def print_extra(extra):
-    rows = (
-        (("sensor id", "sensor-id", str),
-         ("event id", "event-id", str),
-         ("event second", "event-second", str),
-         ),
-        (("type", "type", str),
-         ("datatype", "data-type", str),
-         ("bloglength", "data-length", str),
-         ))
+    rows = [
+        [["sensor id", str(extra["sensor-id"])],
+         ["event id", str(extra["event-id"])],
+         ["event second", str(extra["event-second"])],
+        ],
+        [["type", str(extra["type"])],
+         ["datatype", str(extra["data-type"])],
+         ["bloblength", str(extra["data-length"])],
+     ]]
+
+    body = None
+
+    if extra["type"] == unified2.EXTRA_DATA_TYPE["HTTP_URI"]:
+        rows[1] += [["HTTP URI", str(extra["data"])]]
+    elif extra["type"] == unified2.EXTRA_DATA_TYPE["HTTP_HOSTNAME"]:
+        rows[1] += [["HTTP Hostname", str(extra["data"])]]
+    else:
+        # Don't yet know how to render this.
+        body = extra["data"]
 
     print("\n(ExtraDataHdr)")
     print("\tevent type: %(event-type)d\tevent length: %(event-length)d" % (
@@ -145,9 +163,10 @@ def print_extra(extra):
 
     print("\n(ExtraData)")
     for row in rows:
-        parts = ["%s: %s" % (col[0], col[2](extra[col[1]])) for col in row]
+        parts = ["%s: %s" % (col[0], col[1]) for col in row]
         print("\t" + "\t".join(parts))
-    print(extra["data"])
+    if body:
+        print(body)
 
 def print_record(record):
     if isinstance(record, unified2.Event):
@@ -159,12 +178,15 @@ def print_record(record):
 
 def main():
 
-    filenames = sys.argv[1:]
-    if not filenames:
-        print("usage: %s <file>..." % (sys.argv[0]))
-        return 1
-    
-    reader = unified2.FileRecordReader(*filenames)
+    parser = argparse.ArgumentParser()
+    parser.add_argument("filename", nargs="*")
+    args = parser.parse_args()
+
+    if not args.filename:
+        parser.print_usage()
+        return
+
+    reader = unified2.FileRecordReader(*args.filename)
     for record in reader:
         print_record(record)
 
